<?php
/**
 * 2007-2019 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    PrestaShop SA <contact@prestashop.com>
 *  @copyright 2007-2019 PrestaShop SA
 *  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */

if (! defined('_PS_VERSION_')) {
    exit();
}

class EasycreditCalculator
{

    private $amount;
    private $url;

    public function __construct($amount = 0)
    {
        $this->amount = $amount;
        $this->url = $this->buildCalculationURL();
    }

    protected function buildCalculationURL()
    {
        return sprintf(Easycreditratenkauf::$calc_url, Configuration::get('EASYCREDITRATENKAUF_API_KEY')) . $this->amount;
    }

    public function ratenkaufIsAvailable()
    {
        $response = $this->getResponse();
        return $response !== false && isset($response['ergebnis']);
    }

    public function getURL()
    {
        return $this->url;
    }

    private function getResponse()
    {
        $response = $this->request();
        if ($response['info'] == 409) {
            return false;
        } else {
            return json_decode($response['response'], true);
        }
    }

    private function request()
    {
        $request = curl_init();
        curl_setopt($request, CURLOPT_URL, $this->getURL());
        curl_setopt($request, CURLOPT_HEADER, 0);
        curl_setopt($request, CURLOPT_FAILONERROR, true);
        curl_setopt($request, CURLOPT_TIMEOUT, 60);
        curl_setopt($request, CURLOPT_CONNECTTIMEOUT, 60);

        curl_setopt($request, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($request, CURLOPT_SSL_VERIFYPEER, 1);
        curl_setopt($request, CURLOPT_SSL_VERIFYHOST, 2);
        curl_setopt($request, CURLOPT_SSLVERSION, 6);
        curl_setopt($request, CURLOPT_USERAGENT, 'prestashopPatworxEasycreditRatenkauf');

        $response = curl_exec($request);
        $error = curl_error($request);
        $info = curl_getinfo($request, CURLINFO_HTTP_CODE);
        return array('response' => $response, 'error' => $error, 'info' => $info);
    }
}
