<?php
/**
* 2007-2019 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2019 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

class EasycreditratenkaufConfirmationModuleFrontController extends ModuleFrontController
{
    public function postProcess()
    {
        if (isset($this->context->cookie->easycreditvorgang)) {
            $requestAdapter = new \EasyCredit\Http\Adapter\Curl();
            $dataMapper = new \EasyCredit\Api\DataMapper();
            $request = new EasyCredit\Http\Request(
                \EasyCredit\Config::EASYCREDIT_API_HOSTNAME,
                \EasyCredit\Config::EASYCREDIT_API_PORT,
                $requestAdapter
            );
            $apiClient = new \EasyCredit\Api\ApiClient(
                Configuration::get('EASYCREDITRATENKAUF_API_KEY'),
                Configuration::get('EASYCREDITRATENKAUF_API_TOKEN'),
                $request,
                $dataMapper
            );
            
            $isValidOrder = false;
            $dataFetch = $apiClient->fetch($this->context->cookie->easycreditvorgang);
            if (method_exists($dataFetch, 'getAllgemeineVorgangsdaten')) {
                $allgemeineVorgangsdaten = $dataFetch->getAllgemeineVorgangsdaten();
                if (is_array($allgemeineVorgangsdaten) && isset($allgemeineVorgangsdaten['shopVorgangskennung'])) {
                    if ((int)$allgemeineVorgangsdaten['shopVorgangskennung'] == (int)Context::getContext()->cart->id) {
                        $isValidOrder = true;
                    }
                }
            }

            $decision = $apiClient->decision($this->context->cookie->easycreditvorgang);
            if ($decision->getResult() == 'GRUEN') {
                if ($isValidOrder && Context::getContext()->cookie->easycreditCartHash != md5((float)Context::getContext()->cart->getOrderTotal(true))) {
                    $this->context->cookie->easycredit_error_message = $this->module->l('There has been a problem with your selected payment method. Please chose a different payment method.');
                    Tools::redirect('index.php?controller=order&step=3');
                }
                
                $agreeInstallment = $apiClient->agreeInstallment($this->context->cookie->easycreditvorgang);
                $agreeInstallment = $agreeInstallment->toArray();
                if (isset($agreeInstallment['messages']['messages'][0]['key']) && $agreeInstallment['messages']['messages'][0]['key'] == 'BestellungBestaetigenServiceActivity.Infos.ERFOLGREICH') {
                    $informationen = $apiClient->getFinancingDetails($this->context->cookie->easycreditvorgang);
                    $finanzierung = $informationen->getFinanzierung();
                    
                    $cart = Context::getContext()->cart;
                    $customer = new Customer((int)$cart->id_customer);
                    $secure_key = $customer->secure_key;
                    
                    $payment_status = Configuration::get('PS_OS_PAYMENT');
                    
                    $module_name = $this->module->displayName;
                    $currency_id = (int)Context::getContext()->currency->id;
                    
                    $this->module->validateOrder($cart->id, $payment_status, (float)$finanzierung['bestellwert'], $module_name, '', array(), $currency_id, false, $customer->secure_key);
                    
                    $order_id = Order::getOrderByCartId((int)$cart->id);
                    
                    if ($order_id) {
                        EasycreditLog::updateOrderIdForVorgang($order_id, $this->context->cookie->easycreditvorgang);
                    }
                    
                    if ($order_id && ($secure_key == $customer->secure_key)) {
                        $module_id = $this->module->id;
                        Tools::redirect('index.php?controller=order-confirmation&id_cart='.$cart->id.'&id_module='.$module_id.'&id_order='.$order_id.'&key='.$secure_key);
                    } else {
                        $this->errors[] = $this->module->l('An error occured. Please contact the merchant to have more informations');
                        return $this->setTemplate('error.tpl');
                    }
                } else {
                    $this->context->cookie->easycredit_error_message = $this->module->l('There has been a problem with your selected payment method. Please chose a different payment method.');
                    Tools::redirect('index.php?controller=order&step=3');
                }
            }
        }
        $this->context->cookie->easycredit_error_message = $this->module->l('There has been a problem with your selected payment method. Please chose a different payment method.');
        Tools::redirect('index.php?controller=order&step=3');
    }
}
