<?php
/**
* 2007-2019 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2019 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

class EasycreditratenkaufRedirectModuleFrontController extends ModuleFrontController
{
    /**
     * Do whatever you have to before redirecting the customer on the website of your payment processor.
     */
    public function postProcess()
    {
        $requestAdapter = new \EasyCredit\Http\Adapter\Curl();
        $dataMapper = new \EasyCredit\Api\DataMapper();
        $request = new EasyCredit\Http\Request(
            \EasyCredit\Config::EASYCREDIT_API_HOSTNAME,
            \EasyCredit\Config::EASYCREDIT_API_PORT,
            $requestAdapter
        );
        $apiClient = new \EasyCredit\Api\ApiClient(
            Configuration::get('EASYCREDITRATENKAUF_API_KEY'),
            Configuration::get('EASYCREDITRATENKAUF_API_TOKEN'),
            $request,
            $dataMapper
        );
        
        $customer = new Customer((int)Context::getContext()->cookie->id_customer);
        $billing_address = new Address((int)Context::getContext()->cart->id_address_invoice);
        $delivery_address = new Address((int)Context::getContext()->cart->id_address_delivery);
        $country_billing = new Country((int)$billing_address->id_country);
        $country_delivery = new Country((int)$delivery_address->id_country);
        
        $personaData = new \EasyCredit\Transfer\PersonData();
        $personaData->setFirstName($billing_address->firstname);
        $personaData->setLastName($billing_address->lastname);
        $personaData->setSalutation($customer->id_gender == 2 ? 'FRAU' : 'HERR');

        if (Validate::isBirthDate($customer->birthday) && $customer->birthday != '0000-00-00') {
            $personaData->setBirthDate(new DateTime($customer->birthday));
        }
                
        $billingAddress = new \EasyCredit\Transfer\BillingAddress();
        $billingAddress->setStreet($billing_address->address1);
        if ($billing_address->address2 != '') {
            $billingAddress->setAddressAdditional($billing_address->address2);
        }
        $billingAddress->setCity($billing_address->city);
        $billingAddress->setZip($billing_address->postcode);
        $billingAddress->setCountryCode($country_billing->iso_code);
        
        $deliveryAddress = new \EasyCredit\Transfer\DeliveryAddress();
        $deliveryAddress->setFirstName($delivery_address->firstname);
        $deliveryAddress->setLastName($delivery_address->lastname);
        $deliveryAddress->setStreet($delivery_address->address1);
        if ($delivery_address->address2 != '') {
            $deliveryAddress->setAddressAdditional($delivery_address->address2);
        }
        $deliveryAddress->setCity($delivery_address->city);
        $deliveryAddress->setZip($delivery_address->postcode);
        $deliveryAddress->setCountryCode($country_delivery->iso_code);
        
        $contact = new \EasyCredit\Transfer\Contact();
        $contact->setEmail($customer->email);
        
        $cartInfoCollection = new \EasyCredit\Transfer\CartInfoCollection();
        foreach (Context::getContext()->cart->getProducts() as $cartProduct) {
            $cartInfo = new \EasyCredit\Transfer\CartInfo();
            $cartInfo->setName($cartProduct['name']);
            $cartInfo->setQuantity((int)$cartProduct['cart_quantity']);
            $cartInfo->setPrice((float)$cartProduct['price_wt']);
            if ($cartProduct['ean13'] != '' || $cartProduct['upc'] != '') {
                $articleIdCollection = new \EasyCredit\Transfer\ArticleIdCollection();
                if ($cartProduct['ean13'] != '') {
                    $articleId = new \EasyCredit\Transfer\ArticleId();
                    $articleId->setId($cartProduct['ean13']);
                    $articleId->setType('EAN');
                    $articleIdCollection->addItem($articleId);
                }
                if ($cartProduct['upc'] != '') {
                    $articleId = new \EasyCredit\Transfer\ArticleId();
                    $articleId->setId($cartProduct['upc']);
                    $articleId->setType('UPC');
                    $articleIdCollection->addItem($articleId);
                }
                $cartInfo->setArticleId($articleIdCollection);
            }
            $cartInfoCollection->addItem($cartInfo);
        }
        
        $riskRelatedInfo = new \EasyCredit\Transfer\RiskRelatedInfo();
        $riskRelatedInfo->setCustomerRegistrated(!$customer->isGuest());
        $riskRelatedInfo->setCustomerRegistrationDate(new DateTime($customer->date_add));
        $riskRelatedInfo->setCartItemsCount((int)Context::getContext()->cart->nbProducts());
        $riskRelatedInfo->setOrderCount(count(Order::getCustomerOrders((int)$customer->id)));

        if (isset(Context::getContext()->cart->id_carrier) && (int)Context::getContext()->cart->id_carrier > 0) {
            $cart_carrier = new Carrier((int)Context::getContext()->cart->id_carrier);
            $riskRelatedInfo->setLogisticServiceProvider((string)$cart_carrier->name);
        }

        $ruecksprungAdressen = new \EasyCredit\Transfer\RuecksprungAdressen();
        $ruecksprungAdressen->setUrlErfolg($this->context->link->getModuleLink('easycreditratenkauf', 'check'));
        $ruecksprungAdressen->setUrlAblehnung($this->context->link->getModuleLink('easycreditratenkauf', 'denied'));
        $ruecksprungAdressen->setUrlAbbruch($this->context->link->getModuleLink('easycreditratenkauf', 'canceled'));

        $technicalShopParams = new \EasyCredit\Transfer\TechnicalShopParams();
        $technicalShopParams->setShopPlatformManufacturer('PrestaShop ' . _PS_VERSION_);
        $technicalShopParams->setShopPlatformModuleVersion($this->module->version);
        
        $processInitialize = new \EasyCredit\Transfer\ProcessInitialize();
        $processInitialize->setPersonData($personaData);
        $processInitialize->setBillingAddress($billingAddress);
        $processInitialize->setDeliveryAddress($deliveryAddress);
        $processInitialize->setContact($contact);
        $processInitialize->setAmount((float)Context::getContext()->cart->getOrderTotal(true));
        $processInitialize->setCartInfos($cartInfoCollection);
        $processInitialize->setProcessIdentifierShop(Context::getContext()->cart->id);
        $processInitialize->setRiskRelatedInfo($riskRelatedInfo);
        $processInitialize->setRuecksprungAdressen($ruecksprungAdressen);
        $processInitialize->setIntegrationType('PAYMENT_PAGE');
        $processInitialize->setTechnicalShopParams($technicalShopParams);
        $processInitialize->setShopId(Configuration::get('EASYCREDITRATENKAUF_API_KEY'));

        $processInitializeResponse = $apiClient->init($processInitialize);
        if ($processInitializeResponse->getMessages()) {
            foreach ($processInitializeResponse->getMessages() as $messageArray) {
                foreach ($messageArray as $message) {
                    if ($message['severity'] == 'ERROR') {
                        $this->context->cookie->easycredit_error_message = $message['renderedMessage'];
                        Tools::redirect('index.php?controller=order&step=3');
                    }
                }
            }
        }
        
        Context::getContext()->cookie->easycreditCartHash = md5((float)Context::getContext()->cart->getOrderTotal(true));
        
        $tVorgang = $processInitializeResponse->getTbProcessIdentifier();
        $tDeviceIdent = $processInitializeResponse->getDeviceIdentToken();
        $tFachkennung = $processInitializeResponse->getTechnicalProcessIdentifier();
        $this->context->cookie->easycreditvorgang = $tVorgang;
        $this->context->cookie->easycreditdeviceident = $tDeviceIdent;
        $this->context->cookie->easycreditfachkennung = $tFachkennung;
        
        $newURL = Easycreditratenkauf::$einstieg_url . $tVorgang;
        
        Tools::redirect($newURL);
    }
}
